@@ -15,7 +15,8 @@ export default {
     message: "提示",
     none: "无",
     optional: "可选",
-    loadBalance: "负载均衡"
+    loadBalance: "负载均衡",
+    log: "日志"
   },
   welcome: {
     title: "初来乍到，请多关照",
@@ -91,8 +92,8 @@ export default {
     password: "密码"
   },
   setting: {
-    transparentProxy: "透明代理",
-    transparentType: "透明代理实现方式",
+    transparentProxy: "透明代理/系统代理",
+    transparentType: "透明代理/系统代理实现方式",
     pacMode: "规则端口的分流模式",
     preventDnsSpoofing: "防止DNS污染",
     specialMode: "特殊模式",
@@ -121,7 +122,7 @@ export default {
       updateSubAtIntervals: "每隔一段时间更新订阅（单位：小时）",
       updateGfwlistWhenStart: "服务端启动时更新GFWList",
       updateGfwlistAtIntervals: "每隔一段时间更新GFWList（单位：小时）",
-      dependTransparentMode: "跟随透明代理",
+      dependTransparentMode: "跟随透明代理/系统代理",
       closed: "关闭",
       advanced: "自定义高级设置"
     },
@@ -253,8 +254,8 @@ export default {
     message: "时延测试往往需要花费较长时间，请耐心等待"
   },
   version: {
-    higherVersionNeeded: "该操作需要v2rayA的版本高于{version}",
-    v2rayInvalid: "检测到v2ray-core可能未正确安装，请检查"
+    higherVersionNeeded: "该操作需要 v2rayA 的版本高于{version}",
+    v2rayInvalid: "检测到 geosite.dat, geoip.dat 文件或 v2ray-core 可能未正确安装，请检查"
   },
   about: `<p>v2rayA是V2Ray的一个Web客户端，前端使用Vue.js构建，后端使用Golang构建。</p>
           <p class="about-small">默认端口：</p>
@@ -297,5 +298,10 @@ export default {
       "订阅与节点服务器",
       "导入订阅、节点服务器后，在这里切换和管理你的订阅、普通节点以及订阅节点。"
     ]
+  },
+  log: {
+    logModalTitle: "查看日志",
+    refreshInterval: "刷新间隔",
+    seconds: "秒"
   }
 };
