@@ -3,7 +3,7 @@ package iptables
 import (
 	"github.com/v2rayA/v2rayA/common"
 	"github.com/v2rayA/v2rayA/common/cmds"
-	"github.com/v2rayA/v2rayA/global"
+	"github.com/v2rayA/v2rayA/conf"
 	"golang.org/x/net/nettest"
 	"net"
 	"strconv"
@@ -29,10 +29,14 @@ func GetLocalCIDR() ([]string, error) {
 }
 
 func IsIPv6Supported() bool {
-	if global.GetEnvironmentConfig().ForceIPV6On {
+	switch conf.GetEnvironmentConfig().IPV6Support {
+	case "on":
 		return true
+	case "off":
+		return false
+	default:
 	}
-	if common.IsInDocker() {
+	if common.IsDocker() {
 		return false
 	}
 	if !nettest.SupportsIPv6() {
