@@ -179,7 +179,6 @@ func (v *V2Ray) Configuration(info PriorInfo) (c Configuration, err error) {
 		Protocol: v.Protocol,
 	}
 	port, _ := strconv.Atoi(v.Port)
-	aid, _ := strconv.Atoi(v.Aid)
 	switch strings.ToLower(v.Protocol) {
 	case "vmess", "vless":
 		id := v.ID
@@ -195,7 +194,7 @@ func (v *V2Ray) Configuration(info PriorInfo) (c Configuration, err error) {
 					Users: []coreObj.User{
 						{
 							ID:       id,
-							AlterID:  aid,
+							AlterID:  0,
 							Security: "auto",
 						},
 					},
@@ -294,9 +293,15 @@ func (v *V2Ray) Configuration(info PriorInfo) (c Configuration, err error) {
 				core.StreamSettings.TCPSettings = &tcpSetting
 			}
 		case "h2", "http":
-			core.StreamSettings.HTTPSettings = &coreObj.HttpSettings{
-				Path: v.Path,
-				Host: strings.Split(v.Host, ","),
+			if v.Host != "" {
+				core.StreamSettings.HTTPSettings = &coreObj.HttpSettings{
+					Path: v.Path,
+					Host: strings.Split(v.Host, ","),
+				}
+			} else {
+				core.StreamSettings.HTTPSettings = &coreObj.HttpSettings{
+					Path: v.Path,
+				}
 			}
 		}
 		if strings.ToLower(v.TLS) == "tls" {
