@@ -4,8 +4,8 @@ import (
 	"fmt"
 	"github.com/google/gopacket"
 	"github.com/google/gopacket/pcapgo"
-	v2router "github.com/v2fly/v2ray-core/v4/app/router"
 	"github.com/v2fly/v2ray-core/v4/common/strmatcher"
+	v2router "github.com/v2rayA/v2ray-lib/router"
 	"github.com/v2rayA/v2rayA/common/netTools"
 	"github.com/v2rayA/v2rayA/pkg/util/log"
 	"golang.org/x/net/dns/dnsmessage"
