@@ -50,6 +50,7 @@ type Template struct {
 	Observatory *coreObj.Observatory `json:"observatory,omitempty"`
 	API         *coreObj.APIObject   `json:"api,omitempty"`
 
+	Variant      where.Variant      `json:"-"`
 	CoreVersion  string             `json:"-"`
 	Plugins      []plugin.Server    `json:"-"`
 	OutboundTags []string           `json:"-"`
@@ -464,7 +465,7 @@ func (t *Template) setDNSRouting(routing []coreObj.RoutingRule, supportUDP map[s
 		t.Routing.Rules = append(t.Routing.Rules, dnsOut)
 	}
 	if !supportUDP[firstOutboundTag] {
-		// find a outbound that supports UDP and redirect all leaky UDP traffic to it
+		// find an outbound that supports UDP and redirect all leaky UDP traffic to it
 		var found bool
 		for outbound, support := range supportUDP {
 			if support {
@@ -490,7 +491,7 @@ func (t *Template) setDNSRouting(routing []coreObj.RoutingRule, supportUDP map[s
 			)
 		}
 	} else {
-		if setting.Transparent != configure.TransparentClose {
+		if IsTransparentOn() {
 			t.Routing.Rules = append(t.Routing.Rules,
 				coreObj.RoutingRule{
 					Type:        "field",
@@ -511,12 +512,12 @@ func (t *Template) AppendRoutingRuleByMode(mode configure.RulePortMode, inbounds
 	switch mode {
 	case configure.WhitelistMode:
 		// foreign domains with intranet IP should be proxied first rather than directly connected
-		if asset.LoyalsoldierSiteDatExists() {
+		if asset.DoesV2rayAssetExist("LoyalsoldierSite.dat") {
 			t.Routing.Rules = append(t.Routing.Rules,
 				coreObj.RoutingRule{
 					Type:        "field",
 					OutboundTag: firstOutboundTag,
-					InboundTag:  inbounds,
+					InboundTag:  deepcopy.Copy(inbounds).([]string),
 					Domain:      []string{"ext:LoyalsoldierSite.dat:geolocation-!cn"},
 				})
 		} else {
@@ -524,7 +525,7 @@ func (t *Template) AppendRoutingRuleByMode(mode configure.RulePortMode, inbounds
 				coreObj.RoutingRule{
 					Type:        "field",
 					OutboundTag: firstOutboundTag,
-					InboundTag:  inbounds,
+					InboundTag:  deepcopy.Copy(inbounds).([]string),
 					Domain:      []string{"geosite:geolocation-!cn"},
 				})
 		}
@@ -532,35 +533,35 @@ func (t *Template) AppendRoutingRuleByMode(mode configure.RulePortMode, inbounds
 			coreObj.RoutingRule{
 				Type:        "field",
 				OutboundTag: "direct",
-				InboundTag:  inbounds,
+				InboundTag:  deepcopy.Copy(inbounds).([]string),
 				Domain:      []string{"geosite:cn"},
 			},
 			coreObj.RoutingRule{
 				Type:        "field",
 				OutboundTag: "proxy",
-				InboundTag:  inbounds,
+				InboundTag:  deepcopy.Copy(inbounds).([]string),
 				IP:          []string{"geoip:hk", "geoip:mo"},
 			},
 			coreObj.RoutingRule{
 				Type:        "field",
 				OutboundTag: "direct",
-				InboundTag:  inbounds,
+				InboundTag:  deepcopy.Copy(inbounds).([]string),
 				IP:          []string{"geoip:private", "geoip:cn"},
 			},
 		)
 	case configure.GfwlistMode:
-		if asset.LoyalsoldierSiteDatExists() {
+		if asset.DoesV2rayAssetExist("LoyalsoldierSite.dat") {
 			t.Routing.Rules = append(t.Routing.Rules,
 				coreObj.RoutingRule{
 					Type:        "field",
 					OutboundTag: firstOutboundTag,
-					InboundTag:  inbounds,
+					InboundTag:  deepcopy.Copy(inbounds).([]string),
 					Domain:      []string{"ext:LoyalsoldierSite.dat:gfw"},
 				},
 				coreObj.RoutingRule{
 					Type:        "field",
 					OutboundTag: firstOutboundTag,
-					InboundTag:  inbounds,
+					InboundTag:  deepcopy.Copy(inbounds).([]string),
 					Domain:      []string{"ext:LoyalsoldierSite.dat:greatfire"},
 				})
 		} else {
@@ -568,7 +569,7 @@ func (t *Template) AppendRoutingRuleByMode(mode configure.RulePortMode, inbounds
 				coreObj.RoutingRule{
 					Type:        "field",
 					OutboundTag: firstOutboundTag,
-					InboundTag:  inbounds,
+					InboundTag:  deepcopy.Copy(inbounds).([]string),
 					Domain:      []string{"geosite:geolocation-!cn"},
 				})
 		}
@@ -576,11 +577,11 @@ func (t *Template) AppendRoutingRuleByMode(mode configure.RulePortMode, inbounds
 			coreObj.RoutingRule{
 				Type:        "field",
 				OutboundTag: "direct",
-				InboundTag:  inbounds,
+				InboundTag:  deepcopy.Copy(inbounds).([]string),
 			},
 		)
 	case configure.RoutingAMode:
-		if err := parseRoutingA(t, inbounds); err != nil {
+		if err := parseRoutingA(t, deepcopy.Copy(inbounds).([]string)); err != nil {
 			return err
 		}
 	}
@@ -825,7 +826,7 @@ func (t *Template) setTransparentRouting() (err error) {
 	}
 	return nil
 }
-func (t *Template) AppendDokodemo(tproxy *string, port int, tag string) {
+func (t *Template) AppendDokodemoTProxy(tproxy string, port int, tag string) {
 	dokodemo := coreObj.Inbound{
 		Listen:   "0.0.0.0",
 		Port:     port,
@@ -837,11 +838,8 @@ func (t *Template) AppendDokodemo(tproxy *string, port int, tag string) {
 		Settings: &coreObj.InboundSettings{Network: "tcp,udp"},
 		Tag:      tag,
 	}
-	if tproxy != nil {
-		dokodemo.StreamSettings = &coreObj.StreamSettings{Sockopt: &coreObj.Sockopt{Tproxy: tproxy}}
-		dokodemo.Settings.FollowRedirect = true
-
-	}
+	dokodemo.StreamSettings = &coreObj.StreamSettings{Sockopt: &coreObj.Sockopt{Tproxy: &tproxy}}
+	dokodemo.Settings.FollowRedirect = true
 	t.Inbounds = append(t.Inbounds, dokodemo)
 }
 
@@ -878,6 +876,13 @@ func (t *Template) setDualStack() {
 	if !t.Setting.PortSharing {
 		// copy a group of ipv6 inbounds and set the tag
 		for i := range t.Inbounds {
+			if t.Inbounds[i].Tag == "transparent" && t.Setting.TransparentType == configure.TransparentRedirect {
+				// https://ipset.netfilter.org/iptables-extensions.man.html#lbDK
+				// REDIRECT redirects the packet to the machine itself by changing the destination IP to the primary address of the incoming interface.
+				// So we should listen at 0.0.0.0 instead of 127.0.0.1
+				inbounds6[i].Tag = "THIS_IS_A_DROPPED_TAG"
+				continue
+			}
 			if t.Inbounds[i].Tag == "dns-in" {
 				t.Inbounds[i].Listen = "127.2.0.17"
 				inbounds6[i].Tag = "THIS_IS_A_DROPPED_TAG"
@@ -1024,13 +1029,19 @@ func (t *Template) setInbound() error {
 			t.Inbounds = append(t.Inbounds[:i], t.Inbounds[i+1:]...)
 		}
 	}
-	if t.Setting.Transparent != configure.TransparentClose {
-		var tproxy string
+	if IsTransparentOn() {
 		switch t.Setting.TransparentType {
 		case configure.TransparentTproxy, configure.TransparentRedirect:
-			tproxy = string(t.Setting.TransparentType)
+			t.AppendDokodemoTProxy(string(t.Setting.TransparentType), 32345, "transparent")
+		case configure.TransparentSystemProxy:
+			t.Inbounds = append(t.Inbounds, coreObj.Inbound{
+				Port:     32345,
+				Protocol: "http",
+				Listen:   "127.0.0.1",
+				Tag:      "transparent",
+			})
 		}
-		t.AppendDokodemo(&tproxy, 32345, "transparent")
+
 	}
 	if specialMode.ShouldLocalDnsListen() {
 		if couldListenLocalhost, _ := specialMode.CouldLocalDnsListen(); couldListenLocalhost {
@@ -1078,7 +1089,7 @@ func (t *Template) updatePrivateRouting() {
 }
 
 func (t *Template) optimizeGeoipMemoryOccupation() {
-	if asset.IsGeoipOnlyCnPrivateExists() {
+	if asset.DoesV2rayAssetExist("geoip-only-cn-private.dat") {
 		for i := range t.Routing.Rules {
 			for j := range t.Routing.Rules[i].IP {
 				switch t.Routing.Rules[i].IP[j] {
@@ -1291,6 +1302,7 @@ func (t *Template) resolveOutbounds(
 				// pure outbound
 				outboundTag := sInfo.OutboundName
 				c, err := obj.Configuration(serverObj.PriorInfo{
+					Variant:     t.Variant,
 					CoreVersion: t.CoreVersion,
 					Tag:         outboundTag,
 					PluginPort:  sInfo.PluginPort,
@@ -1320,6 +1332,7 @@ func (t *Template) resolveOutbounds(
 			// the v2ray outbound is shared by balancers
 			outboundTag := Ps2OutboundTag(obj.GetName())
 			c, err := obj.Configuration(serverObj.PriorInfo{
+				Variant:     t.Variant,
 				CoreVersion: t.CoreVersion,
 				Tag:         outboundTag,
 				PluginPort:  balancerPluginPort,
@@ -1460,7 +1473,7 @@ func NewTemplate(serverInfos []serverInfo, setting *configure.Setting) (t *Templ
 	if err != nil {
 		return nil, fmt.Errorf("error occurs while reading template json, please check whether templateJson variable is correct json format")
 	}
-	tmplJson.CoreVersion, _ = where.GetV2rayServiceVersion()
+	tmplJson.Variant, tmplJson.CoreVersion, _ = where.GetV2rayServiceVersion()
 	t = &tmplJson
 	t.Setting = setting
 	// log
@@ -1509,7 +1522,7 @@ func NewTemplate(serverInfos []serverInfo, setting *configure.Setting) (t *Templ
 		return nil, err
 	}
 	//transparent routing
-	if t.Setting.Transparent != configure.TransparentClose {
+	if IsTransparentOn() {
 		if err = t.setTransparentRouting(); err != nil {
 			return nil, err
 		}
@@ -1684,7 +1697,7 @@ func WriteV2rayConfig(content []byte) (err error) {
 
 func NewEmptyTemplate(setting *configure.Setting) (t *Template) {
 	t = new(Template)
-	t.CoreVersion, _ = where.GetV2rayServiceVersion()
+	t.Variant, t.CoreVersion, _ = where.GetV2rayServiceVersion()
 	if setting != nil {
 		setting.FillEmpty()
 	} else {
@@ -1695,7 +1708,7 @@ func NewEmptyTemplate(setting *configure.Setting) (t *Template) {
 }
 
 func (t *Template) checkAndSetMark(o *coreObj.OutboundObject, mark int) {
-	if t.Setting.Transparent == configure.TransparentClose {
+	if !IsTransparentOn() {
 		return
 	}
 	if o.StreamSettings == nil {
@@ -1709,9 +1722,10 @@ func (t *Template) checkAndSetMark(o *coreObj.OutboundObject, mark int) {
 
 func (t *Template) InsertMappingOutbound(o serverObj.ServerObj, inboundPort string, udpSupport bool, pluginPort int, protocol string) (err error) {
 	if t.CoreVersion == "" {
-		t.CoreVersion, _ = where.GetV2rayServiceVersion()
+		t.Variant, t.CoreVersion, _ = where.GetV2rayServiceVersion()
 	}
 	c, err := o.Configuration(serverObj.PriorInfo{
+		Variant:     t.Variant,
 		CoreVersion: t.CoreVersion,
 		Tag:         "outbound" + inboundPort,
 		PluginPort:  pluginPort,
